==> downloads.html?file=gigkalender_v1.2.61_059.zip: gigkalender/news/backend_showNews.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  // Überschrift ausgeben
    echo '<p class="Headline">'.$L_Headline36.':</p>';
  // Inhalt hier einfügen
        if (isset($_REQUEST['newsid'])) { $NewsID = $_REQUEST['newsid']; }
        $sql = "SELECT * FROM ".$prefix."news WHERE NewsID = '$NewsID'";
        $resultat = mysql_db_query($db_name, $sql);
        while ($row = mysql_fetch_array($resultat))
        {
          extract($row);


        echo '<table summary="AddNews">';
            // Title
               echo '<tr>
                  <td align="right" valign="top">'.$L_NewsTitle.':</td>
                  <td>'.$Title.'</td>
                </tr>';
            // Text

          echo '<tr>
                  <td align="right" valign="top">'.$L_NewsText.':</td>
                  <td>'.$Text.'</td>
                </tr>';

            // Publish

            echo '<tr>
                    <td align="right" valign="top">'.$L_NewsPublish.':</td>
                    <td>';

            if ($Publish=="1") echo $L_091;
            if ($Publish=="0") echo $L_092;
            echo '</td>
            </tr>';



          // Button
          echo '
        	   <tr>
              <td></td>
              <td>
                <input type="button" value="'.$L_Button04.'" onclick="history.go(-1)" class="button" />
              </td>
        	   </tr>
      	   </table>';}

    // Inhalt zuende
?>

==> downloads.html?file=gigkalender_v1.2.81.zip: gigkalender/news/backend_showNews.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  // Überschrift ausgeben
    echo '<p class="Headline">'.$L_Headline36.':</p>';
  // Inhalt hier einfügen
        if (isset($_REQUEST['newsid'])) { $NewsID = $_REQUEST['newsid']; }
        $SQLQuery = "SELECT * FROM ".$prefix."news WHERE NewsID = '$NewsID'";
        $Result = mysqli_query($db, $SQLQuery);
        while ($row = mysqli_fetch_array($Result))
        {
          extract($row);


        echo '<table summary="AddNews">';
            // Title
               echo '<tr>
                  <td align="right" valign="top">'.$L_NewsTitle.':</td>
                  <td>'.$Title.'</td>
                </tr>';
            // Text

          echo '<tr>
                  <td align="right" valign="top">'.$L_NewsText.':</td>
                  <td>'.$Text.'</td>
                </tr>';

            // Publish

            echo '<tr>
                    <td align="right" valign="top">'.$L_NewsPublish.':</td>
                    <td>';

            if ($Publish=="1") echo $L_091;
            if ($Publish=="0") echo $L_092;
            echo '</td>
            </tr>';



          // Button
          echo '
        	   <tr>
              <td></td>
              <td>
                <input type="button" value="'.$L_Button04.'" onclick="history.go(-1)" class="button" />
              </td>
        	   </tr>
      	   </table>';}

    // Inhalt zuende
?>
